v0.0.1 (October, 28th 2020)
===========================

First release by the oemof developing group.

Contributors
^^^^^^^^^^^^^^^^^^^^

* Jann Launer
* Johannes Röder
* Joris Zimmermann
* Marie-Claire Gering
* oakca
